__version__ = "0.5.11"
__git_commiter_name__ = "wiggin15"
__git_commiter_email__ = "wiggin15@yahoo.com"
__git_branch__ = '(Not currently on any branch)'
__git_remote_tracking_branch__ = '(No remote tracking)'
__git_remote_url__ = '(Not remote tracking)'
__git_head_hash__ = '40f2c31d45ebee00ee3c0ef22030a1cc45a43e87'
__git_head_subject__ = 'Finished release v0.5.11.'
__git_head_message__ = ''
__git_dirty_diff__ = ''